==> skirental_frontend_api-0.0.9.gem: app/controllers/skirental_frontend_api/shop_data_controller.rb <==
# encoding: utf-8
require_dependency "skirental_frontend_api/application_controller"

module SkirentalFrontendApi
    class ShopDataController < ApplicationController
        before_action :set_shop_params

        def show
            @shop_datum = SkirentalApi::Client.shop_datum(@shop_id, @shop_lang)
        end

        def product_categories
            @product_categories = SkirentalApi::Client.categories(@shop_id, @shop_lang)
        end

        def packages
            @product_packages = SkirentalApi::Client.packages(@shop_id, @product_category_id, @start_date, @duration, @customer_group_id, @shop_lang)
            render :json => @product_packages
        end

        def products
            @products = SkirentalApi::Client.products(@shop_id, @product_category_id, @start_date, @duration, @customer_group_id, @shop_lang)
            render :json => @products
        end

        private

        def set_shop_params
            @shop_id             = shop_datum_params[:shop_id]
            @shop_lang           = shop_datum_params[:lang]
            @product_category_id = shop_datum_params[:product_category_id]
            @start_date          = shop_datum_params[:start]
            @duration            = shop_datum_params[:duration]
            @customer_group_id   = shop_datum_params[:customer_group_id]
        end

        # Only allow a trusted parameter "white list" through.
        def shop_datum_params
            params.permit(:shop_id, :lang, :product_category_id, :start, :duration, :customer_group_id)
        end
    end
end

==> skirental_frontend_api-0.0.13.gem: app/controllers/skirental_frontend_api/shop_data_controller.rb <==
# encoding: utf-8
require_dependency "skirental_frontend_api/application_controller"

module SkirentalFrontendApi
    class ShopDataController < ApplicationController
        before_action :set_shop_params

        def show
            @shop_datum = SkirentalApi::Client.shop_datum(@shop_id, @shop_lang)
        end

        def product_categories
            @product_categories = SkirentalApi::Client.categories(@shop_id, @shop_lang)
        end

        def packages
            @product_packages = SkirentalApi::Client.packages(@shop_id, @product_category_id, @start_date, @duration, @customer_group_id, @shop_lang)
            render :json => @product_packages
        end

        def products
            @products = SkirentalApi::Client.products(@shop_id, @product_category_id, @start_date, @duration, @customer_group_id, @shop_lang)
            render :json => @products
        end

        def metrics
            @metrics = SkirentalApi::Client.metrics(@shop_id, @metric_type, @shop_lang)
            render :json => @metrics
        end

        private

        def set_shop_params
            @shop_id             = shop_datum_params[:shop_id]
            @shop_lang           = shop_datum_params[:lang]
            @product_category_id = shop_datum_params[:product_category_id]
            @start_date          = shop_datum_params[:start]
            @duration            = shop_datum_params[:duration]
            @customer_group_id   = shop_datum_params[:customer_group_id]
            @metric_type         = shop_datum_params[:metric_type]
        end

        # Only allow a trusted parameter "white list" through.
        def shop_datum_params
            params.permit(:shop_id, :lang, :product_category_id, :start, :duration, :customer_group_id, :metric_type)
        end
    end
end
